@@ -19,7 +19,7 @@ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
-
+import asyncio
 from typing import (
     Optional,
     Union,
@@ -34,10 +34,12 @@ from .exceptions import APIException,NoToken
 from .utils import APIBaseURL,requires_token
 
 
+
+
 class WaifuAioClient:
     def __init__(
         self,
-        session: aiohttp.ClientSession = aiohttp.ClientSession(),
+        session: aiohttp.ClientSession = None,
         token: Optional[str] = None,
         appname: Optional[str] = None,
 
@@ -56,7 +58,7 @@ class WaifuAioClient:
     async def __aenter__(self):
         return self
 
-    async def __aexit__(self, exception_type, exception, traceback):
+    async def __aexit__(self, exception_type, exception, exception_traceback):
         await self.close()
 
     async def close(self) -> None:
@@ -64,8 +66,13 @@ class WaifuAioClient:
         if self.session is not None:
             await self.session.close()
 
+    async def _get_session(self):
+        if not self.session:
+            self.session=aiohttp.ClientSession()
+        return self.session
+
     async def _make_request(self, url: str, method: str, *args, **kwargs):
-        response = await getattr(self.session, method)(url, *args, **kwargs)
+        response = await getattr(await self._get_session(), method)(url, *args, **kwargs)
         infos= await response.json()
         if response.status==200:
             return infos
